@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FWUPD_DEVICE_H
-#define __FWUPD_DEVICE_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -63,6 +62,9 @@ void		 fwupd_device_set_version_lowest	(FwupdDevice	*device,
 const gchar	*fwupd_device_get_version_bootloader	(FwupdDevice	*device);
 void		 fwupd_device_set_version_bootloader	(FwupdDevice	*device,
 							 const gchar	*version_bootloader);
+FwupdVersionFormat fwupd_device_get_version_format	(FwupdDevice	*device);
+void		 fwupd_device_set_version_format	(FwupdDevice	*device,
+							 FwupdVersionFormat version_format);
 guint32		 fwupd_device_get_flashes_left		(FwupdDevice	*device);
 void		 fwupd_device_set_flashes_left		(FwupdDevice	*device,
 							 guint32	flashes_left);
@@ -102,6 +104,11 @@ gboolean	 fwupd_device_has_guid			(FwupdDevice	*device,
 							 const gchar	*guid);
 GPtrArray	*fwupd_device_get_guids			(FwupdDevice	*device);
 const gchar	*fwupd_device_get_guid_default		(FwupdDevice	*device);
+void		 fwupd_device_add_instance_id		(FwupdDevice	*device,
+							 const gchar	*instance_id);
+gboolean	 fwupd_device_has_instance_id		(FwupdDevice	*device,
+							 const gchar	*instance_id);
+GPtrArray	*fwupd_device_get_instance_ids		(FwupdDevice	*device);
 void		 fwupd_device_add_icon			(FwupdDevice	*device,
 							 const gchar	*icon);
 GPtrArray	*fwupd_device_get_icons			(FwupdDevice	*device);
@@ -122,7 +129,7 @@ FwupdRelease	*fwupd_device_get_release_default	(FwupdDevice	*device);
 gint		 fwupd_device_compare			(FwupdDevice	*device1,
 							 FwupdDevice	*device2);
 
+FwupdDevice	*fwupd_device_from_variant		(GVariant	*value);
+GPtrArray	*fwupd_device_array_from_variant	(GVariant	*value);
+
 G_END_DECLS
-
-#endif /* __FWUPD_DEVICE_H */
-
